==> text-formatting-0.22.1.tgz: package/__tests__/superscript.test.js <==
/**
 * @jest-environment jsdom
 */

/** @jsx psx */
import { SpecRegistry } from '@bangle.dev/core';
import {
  psx,
  renderTestEditor,
  sendKeyToPm,
  setSelectionNear,
} from '@bangle.dev/core/test-helpers/test-helpers';

import { superscript, subscript } from '../index';

const toggleKey = 'Ctrl-s';
const specRegistry = new SpecRegistry([subscript.spec(), superscript.spec()]);
const plugins = [
  superscript.plugins({
    keybindings: {
      toggleSuperscript: toggleKey,
    },
  }),
];
describe('Basic', () => {
  const testEditor = renderTestEditor({
    specRegistry,
    plugins,
  });

  test('toggles Strike correctly', async () => {
    const { view } = testEditor(
      <doc>
        <para>hello [world]</para>
      </doc>,
    );

    sendKeyToPm(view, toggleKey);

    expect(view.state.doc).toEqualDocument(
      <doc>
        <para>
          hello <superscript>world</superscript>
        </para>
      </doc>,
    );

    sendKeyToPm(view, toggleKey);

    expect(view.state.doc).toEqualDocument(
      <doc>
        <para>hello world</para>
      </doc>,
    );
  });

  test('queryIsSuperscriptActive works correctly', async () => {
    const { view } = testEditor(
      <doc>
        <para>hello [world]</para>
      </doc>,
    );

    expect(superscript.commands.queryIsSuperscriptActive()(view.state)).toBe(
      false,
    );

    superscript.commands.toggleSuperscript()(view.state, view.dispatch, view);

    expect(view.state.doc).toEqualDocument(
      <doc>
        <para>
          hello <superscript>world</superscript>
        </para>
      </doc>,
    );

    setSelectionNear(view, 9);

    expect(superscript.commands.queryIsSuperscriptActive()(view.state)).toBe(
      true,
    );
  });
});

==> text-formatting-0.26.4.tgz: package/__tests__/superscript.test.js <==
/**
 * @jest-environment jsdom
 */

/** @jsx psx */
import { SpecRegistry } from '@bangle.dev/core';
import {
  psx,
  renderTestEditor,
  sendKeyToPm,
  setSelectionNear,
} from '@bangle.dev/test-helpers';
import { subscript, superscript } from '../index';

const toggleKey = 'Ctrl-s';
const specRegistry = new SpecRegistry([subscript.spec(), superscript.spec()]);
const plugins = [
  superscript.plugins({
    keybindings: {
      toggleSuperscript: toggleKey,
    },
  }),
];
describe('Basic', () => {
  const testEditor = renderTestEditor({
    specRegistry,
    plugins,
  });

  test('toggles Strike correctly', async () => {
    const { view } = testEditor(
      <doc>
        <para>hello [world]</para>
      </doc>,
    );

    sendKeyToPm(view, toggleKey);

    expect(view.state.doc).toEqualDocument(
      <doc>
        <para>
          hello <superscript>world</superscript>
        </para>
      </doc>,
    );

    sendKeyToPm(view, toggleKey);

    expect(view.state.doc).toEqualDocument(
      <doc>
        <para>hello world</para>
      </doc>,
    );
  });

  test('queryIsSuperscriptActive works correctly', async () => {
    const { view } = testEditor(
      <doc>
        <para>hello [world]</para>
      </doc>,
    );

    expect(superscript.commands.queryIsSuperscriptActive()(view.state)).toBe(
      false,
    );

    superscript.commands.toggleSuperscript()(view.state, view.dispatch, view);

    expect(view.state.doc).toEqualDocument(
      <doc>
        <para>
          hello <superscript>world</superscript>
        </para>
      </doc>,
    );

    setSelectionNear(view, 9);

    expect(superscript.commands.queryIsSuperscriptActive()(view.state)).toBe(
      true,
    );
  });
});
